==> v0.4.2.tar.gz: social/l10n/fi.js <==
OC.L10N.register(
    "social",
    {
    "Social" : "Sosiaalinen",
    "Help" : "Ohje",
    ".well-known/webfinger isn't properly set up!" : ".well-known/webfinger ei ole asetettu oikein!",
    "Open documentation" : "Avaa dokumentaatio",
    "Social app setup" : "Sosiaalinen -sovelluksen asennus",
    "ActivityPub requires a fixed URL to make entries unique. Note that this can not be changed later without resetting the Social app." : "ActivityPub vaatii kiinteän URL -osoitteen, jotta julkaisuista tulee yksilöllisiä. Huomaa, ettei tätä voi myöhemmin muuttaa nollamatta koko sovellusta.",
    "ActivityPub URL base" : "ActivityPub URL:n alkuosa",
    "Finish setup" : "Viimeistele asennus",
    "The Social app needs to be set up by the server administrator." : "Sosiaalinen -sovellus täytyy asentaa pääkäyttäjän toimesta.",
    "Home" : "Koti",
    "Direct messages" : "Suoraviestit",
    "Notifications" : "Ilmoitukset",
    "Profile" : "Profiili",
    "Liked" : "Tykätty",
    "Local timeline" : "Paikallinen aikajana",
    "Global timeline" : "Julkinen aikajana",
    "Following" : "Seuraa",
    "Post publicly" : "Julkaisun julkisuus",
    "Post to followers" : "Julkaise seuraajille",
    "Post to recipients" : "Julkaise vastaanottajille",
    "Post unlisted" : "Listaamaton julkaisu",
    "Public" : "Julkinen",
    "Post to public timelines" : "Julkaise julkisille aikajanoille",
    "Unlisted" : "Listaamaton",
    "Do not post to public timelines" : "Älä julkaise julkisille aikajanoille",
    "Followers" : "Seuraajat",
    "Post to followers only" : "Julkaise vain seuraajille",
    "Direct" : "Suoraan",
    "Post to mentioned users only" : "Julkaise vain mainituille käyttäjille",
    "Unfollow" : "Lopeta seuraaminen",
    "Follow" : "Seuraa",
    "posts" : "julkaisut",
    "following" : "seuraa",
    "followers" : "seuraajat",
    "No results found" : "Ei tuloksia",
    "There were no results for your search:" : "Hakusi ei tuottanut tuloksia:",
    "Searching for" : "Haetaan",
    "No posts found" : "Julkaisuja ei löytynyt",
    "Posts from people you follow will show up here" : "Seuraamiesi käyttäjien julkaisut näkyvät täällä",
    "No direct messages found" : "Ei suoria viestejä",
    "Posts directed to you will show up here" : "Sinulle osoitetut julkaisut näkyvät täällä",
    "No local posts found" : "Ei paikallisia julkaisuja",
    "Posts from other people on this instance will show up here" : "Muiden ihmisten tähän asennukseen kirjoitetut julkaisut näkyvät täällä",
    "No notifications found" : "Ilmoituksia ei löytynyt",
    "You haven't receive any notifications yet" : "Et ole vielä saanut yhtäkään ilmoitusta",
    "No global posts found" : "Yleisiä julkaisuja ei löytynyt",
    "Posts from federated instances will show up here" : "Yhteenliitettyihin asennuksiin tehdyt julkaisut näkyvät täällä",
    "Reply" : "Vastaa",
    "More actions" : "Lisää toimintoja",
    "Delete post" : "Poista viesti",
    "Hello" : "Hei",
    "Please confirm that you want to follow this account:" : "Vahvista että haluat seurata tätä tiliä:",
    "You are following this account" : "Seuraat tätä tiliä",
    "Close" : "Sulje",
    "Continue" : "Jatka",
    "User not found" : "Käyttäjää ei löydy",
    "Nextcloud becomes part of the federated social networks!" : "Nextcloudista tulee yhteenliitettyjen sosiaalisten verkostojen osa!",
    "Since you are new to Social, start by following the official Nextcloud account so you don't miss any news" : "Koska olet uusi käyttäjä, aloita seuraamalla virallista Nextcloud -tiliä ettet jää uutisista paitsi",
    "Follow Nextcloud on mastodon.xyz" : "Seuraa Nextcloudia mastodon.xyz:ssa"
},
"nplurals=2; plural=(n != 1);");

==> v0.6.0-rc1.tar.gz: social/l10n/fi.js <==
OC.L10N.register(
    "social",
    {
    "Social" : "Sosiaalinen",
    "Social notifications" : "Sosiaaliset ilmoitukset",
    "Help" : "Ohje",
    ".well-known/webfinger isn't properly set up!" : ".well-known/webfinger ei ole asetettu oikein!",
    "Open documentation" : "Avaa dokumentaatio",
    "Social app setup" : "Sosiaalinen -sovelluksen asennus",
    "ActivityPub URL base" : "ActivityPub URL:n alkuosa",
    "Finish setup" : "Viimeistele asennus",
    "The Social app needs to be set up by the server administrator." : "Sosiaalinen -sovellus täytyy asentaa pääkäyttäjän toimesta.",
    "Home" : "Koti",
    "Direct messages" : "Suoraviestit",
    "Notifications" : "Ilmoitukset",
    "Profile" : "Profiili",
    "Liked" : "Tykätty",
    "Local timeline" : "Paikallinen aikajana",
    "Global timeline" : "Julkinen aikajana",
    "Following" : "Seuraa",
    "In reply to" : "Vastauksena",
    "Close reply" : "Sulje vastaus",
    "Add attachment" : "Lisää liite",
    "Add emoji" : "Lisää emoji",
    "Uploading..." : "Lähetetään...",
    "Delete" : "Poista",
    "Post" : "Lähetä",
    "Post to followers" : "Julkaise seuraajille",
    "Post publicly" : "Julkaisun julkisuus",
    "Post to recipients" : "Julkaise vastaanottajille",
    "Post unlisted" : "Listaamaton julkaisu",
    "Unfollow" : "Lopeta seuraaminen",
    "Follow" : "Seuraa",
    "posts" : "julkaisut",
    "following" : "seuraa",
    "followers" : "seuraajat",
    "Website" : "Verkkosivu",
    "No results found" : "Ei tuloksia",
    "There were no results for your search:" : "Hakusi ei tuottanut tuloksia:",
    "Searching for" : "Haetaan",
    "{account} liked your post" : "{account} tykkäsi viestistäsi",
    "No posts found" : "Julkaisuja ei löytynyt",
    "Posts from people you follow will show up here" : "Seuraamiesi käyttäjien julkaisut näkyvät täällä",
    "No direct messages found" : "Ei suoria viestejä",
    "Posts directed to you will show up here" : "Sinulle osoitetut julkaisut näkyvät täällä",
    "No local posts found" : "Ei paikallisia julkaisuja",
    "Posts from other people on this instance will show up here" : "Muiden ihmisten tähän asennukseen kirjoitetut julkaisut näkyvät täällä",
    "No notifications found" : "Ilmoituksia ei löytynyt",
    "You have not received any notifications yet" : "Et ole vielä saanut yhtäkään ilmoitusta",
    "No global posts found" : "Yleisiä julkaisuja ei löytynyt",
    "Posts from federated instances will show up here" : "Yhteenliitettyihin asennuksiin tehdyt julkaisut näkyvät täällä",
    "No replies found" : "Vastauksia ei löytynyt",
    "Reply" : "Vastaa",
    "Like" : "Tykkää",
    "Undo Like" : "Kumoa tykkääminen",
    "{account} is following you" : "{account} seuraa sinua",
    "Deny" : "Kiellä",
    "Hello" : "Hei",
    "Please confirm that you want to follow this account:" : "Vahvista että haluat seurata tätä tiliä:",
    "You are following this account" : "Seuraat tätä tiliä",
    "Close" : "Sulje",
    "Continue" : "Jatka",
    "User not found" : "Käyttäjää ei löydy",
    "Nextcloud becomes part of the federated social networks!" : "Nextcloudista tulee yhteenliitettyjen sosiaalisten verkostojen osa!",
    "Since you are new to Social, start by following the official Nextcloud account so you don't miss any news" : "Koska olet uusi käyttäjä, aloita seuraamalla virallista Nextcloud -tiliä ettet jää uutisista paitsi",
    "Follow Nextcloud on mastodon.xyz" : "Seuraa Nextcloudia mastodon.xyz:ssa",
    "Public" : "Julkinen",
    "Unlisted" : "Listaamaton",
    "Followers" : "Seuraajat",
    "Direct" : "Suoraan"
},
"nplurals=2; plural=(n != 1);");
